# Adding models or languages

You can extend Coqui by implementing new model architectures or adding front
ends for new languages. See the pages below for more details. The [project
structure](../project_structure.md) and [contribution
guidelines](../contributing.md) may also be helpful. Please open a pull request
with your changes to share back the improvements with the community.

```{toctree}
:maxdepth: 1

implementing_a_new_model
implementing_a_new_language_frontend
```
